<?php

class ModelModuleNewsletter2Go extends Model
{

    /**
     * Checks API users credentials
     * @param string $username
     * @param string $apikey
     * @return bool true if user has rights, otherwise false
     */
    public function validateUser($username, $apikey)
    {
        $result = $this->db->query('SELECT * FROM `' . DB_PREFIX . "user` WHERE username = '$username' AND n2go_apikey = '$apikey' AND n2go_api_enabled = 1");

        return $result->num_rows == 1;
    }

    /**
     * Sets newsletter flag on 0 for user(s) with given e-mail
     * @param string $email
     */
    public function unsubscribeByEmail($email)
    {
        $this->event->trigger('pre.customer.edit.newsletter');
        $result = $this->db->query("UPDATE `" . DB_PREFIX . "customer` SET newsletter = 0 WHERE email = '$email'");
        $this->event->trigger('post.customer.edit.newsletter');

        return $result;
    }

    public function getCustomers($criteria = array())
    {
        $select = 'SELECT 
                    c.customer_id AS crm_id, 
                    c.firstname AS firstname, 
                    c.lastname AS lastname, 
                    c.email AS mail, 
                    c.newsletter AS subscribed, 
                    c.telephone AS mobile, 
                    a.company AS company_name, 
                    a.address_1 AS street, 
                    a.city AS city, 
                    co.name AS country ';
        $from = ' FROM ' . DB_PREFIX . 'customer c 
                    LEFT JOIN ' . DB_PREFIX . 'address a ON a.address_id = c.address_id 
                    LEFT JOIN ' . DB_PREFIX . 'country co ON co.country_id = a.country_id ';


        if ($criteria['subscribed']) {
            $from .= ' WHERE newsletter = 1 ';
        }
        
        $resultTotal = $this->db->query('SELECT COUNT(*) AS total ' . $from);
        
        if ($criteria['limit']) {
            $criteria['offset'] = ($criteria['offset'] ? : 0);
            $from .= ' LIMIT ' . $criteria['offset'] . ', ' . $criteria['limit'];
        }

        $resultCustomers = $this->db->query($select . $from);
        
        $result = array('total' => $resultTotal->row['total'], 'customers' => $resultCustomers->rows);
        
        return $result;
    }

    public function getProduct($id, $lang)
    {
        $query = 'SELECT 
                    p.product_id AS id, 
                    p.price AS oldPriceNet, 
                    p.price AS newPriceNet, 
                    p.price AS oldPrice, 
                    p.price AS newPrice, 
                    mf.name AS brand, 
                    p.model AS model, 
                    pd.name AS name, 
                    pd.description AS description, 
                    ta.rate AS vat 
                FROM ' . DB_PREFIX . 'product p 
                    LEFT JOIN ' . DB_PREFIX . 'manufacturer mf ON mf.manufacturer_id = p.manufacturer_id 
                    LEFT JOIN ' . DB_PREFIX . 'product_description pd ON pd.product_id = p.product_id 
                    LEFT JOIN ' . DB_PREFIX . 'language lg ON lg.language_id = pd.language_id 
                    LEFT JOIN (SELECT tax_class_id, tax_rate_id, MIN(priority) FROM ' . DB_PREFIX . 'tax_rule GROUP BY tax_class_id) tr ON tr.tax_class_id = p.tax_class_id 
                    LEFT JOIN ' . DB_PREFIX . 'tax_rate ta ON ta.tax_rate_id = tr.tax_rate_id '
                . "WHERE p.product_id = $id AND lg.code = '$lang'";

        $result = $this->db->query($query);
        $product = $result->row;
        $product['images'] = array();
        $product['link'] = substr($this->url->link('product/product', 'product_id=' . $id), strlen(HTTP_SERVER));
        $product['url'] = HTTP_SERVER;
        $product['shortDescription'] = null;
        if ($product['vat']) {
            $product['oldPrice'] = $product['newPrice'] = round($product['oldPriceNet'] * (1 + $product['vat'] * 0.01), 2);
            $product['vat'] = round($product['vat'] * 0.01, 2);
        }

        $product['oldPriceNet'] = $product['newPriceNet'] = round($product['oldPriceNet'], 2);
        
        $query = 'SELECT image FROM ' . DB_PREFIX . 'product_image WHERE product_id = ' . $id;
        $result = $this->db->query($query);
        foreach ($result->rows as $image) {
            $product['images'][] = HTTP_SERVER . 'image/' . $image['image'];
        }

        return $product;
    }
}
